function MoneyManager:get_secured_mandatory_bags_money()
  local stars = managers.job:has_active_job() and managers.job:current_difficulty_stars() or 0
	local money_multiplier = self:get_contract_difficulty_multiplier(stars)
	local bag_skill_bonus = managers.player:upgrade_value("player", "secured_bags_money_multiplier", 1)
	local mandatory_value = managers.loot:get_secured_mandatory_bags_value()
  local mandatory_risk = math.round(mandatory_value * money_multiplier)
	local mandatory_mult = self:get_tweak_value("money_manager", "mandatory_mult")
	local offshore_rate = self:get_tweak_value("money_manager", "offshore_rate")

	return math.round((mandatory_value + mandatory_risk) * bag_skill_bonus * mandatory_mult / offshore_rate)
end

function MoneyManager:get_secured_bonus_bag_value(carry_id, multiplier)
	local bag_value = managers.money:get_bag_value(carry_id, multiplier)
	local mandatory_mult = not managers.loot:is_bonus_bag(carry_id) and self:get_tweak_value("money_manager", "mandatory_mult") or 1
	local bag_skill_bonus = managers.player:upgrade_value("player", "secured_bags_money_multiplier", 1)
	local stars = managers.job:has_active_job() and managers.job:current_difficulty_stars() or 0
	local money_multiplier = self:get_contract_difficulty_multiplier(stars)
	local bag_risk = math.round(bag_value * money_multiplier)
	local offshore_rate = self:get_tweak_value("money_manager", "offshore_rate")

	return math.round((bag_value + bag_risk) * bag_skill_bonus * mandatory_mult / offshore_rate)
end

function MoneyManager:get_money_by_params(params)
	local job_id = params.job_id
	local difficulty_stars = params.difficulty_stars or params.risk_stars or 0
	local num_winners = params.num_winners or 1
	local on_last_stage = params.on_last_stage
	local money_multiplier = self:get_contract_difficulty_multiplier(difficulty_stars)
	local cash_skill_bonus, bag_skill_bonus = managers.player:get_skill_money_multiplier(managers.groupai and managers.groupai:state():whisper_mode())
	local bonus_bags = params.bonus_bags_value or managers.loot:get_secured_bonus_bags_value(params.level_id)
	local mandatory_bags = params.mandatory_bags_value or managers.loot:get_secured_mandatory_bags_value()
	local real_small_value = params.small_value or math.round(managers.loot:get_real_total_small_loot_value())
	local bonus_vehicles = params.vehicle_value or math.round(managers.loot:get_secured_bonus_bags_value(nil, true))
	local offshore_rate = self:get_tweak_value("money_manager", "offshore_rate")
	local mandatory_mult = self:get_tweak_value("money_manager", "mandatory_mult")
	local total_payout, stage_value, stage_risk, job_value, job_risk, crew_value = 0, 0, 0, 0, 0, 0
	local bag_value, bag_risk, vehicle_value, vehicle_risk, small_value, small_risk = 0, 0, 0, 0, 0, 0
	local static_value, base_static_value, risk_static_value = self:get_money_by_job(job_id, difficulty_stars + 1)
	static_value = static_value * cash_skill_bonus
	base_static_value = static_value - risk_static_value
	if not static_value then log("not static_value") end

	-- SMALL LOOT --
	small_value = real_small_value + managers.loot:get_real_total_postponed_small_loot_value()
	local max_small_loot_value = tweak_data:get_value("money_manager", "max_small_loot_value")
	small_value = small_value < max_small_loot_value and small_value or max_small_loot_value

	-- LAST STAGE --
	if on_last_stage then
		bag_value = (bonus_bags + mandatory_bags * mandatory_mult) * bag_skill_bonus / offshore_rate
		bag_risk = math.round(bag_value * money_multiplier)
		vehicle_value = bonus_vehicles * cash_skill_bonus / offshore_rate
		vehicle_risk = math.round(vehicle_value * money_multiplier)
		total_payout = math.round((static_value / offshore_rate) + bag_value + bag_risk + vehicle_value + vehicle_risk + small_value)
		crew_value = total_payout
		total_payout = math.round(total_payout * self:get_tweak_value("money_manager", "alive_humans_multiplier", num_winners))
		crew_value = total_payout - crew_value
		job_risk = math.round(risk_static_value / offshore_rate) or 0
		job_value = math.round(static_value / offshore_rate) - job_risk or 0
	else
		total_payout = small_value
	end

	-- HOLDOUT --
	if managers.skirmish:is_skirmish() then
		local skirmish_payout = managers.skirmish:current_ransom_amount()
		total_payout = math.round(total_payout + skirmish_payout) or 0
	end

	-- MUTATORS --
	local mutators_multiplier = managers.mutators:get_cash_multiplier()
	local original_total_payout = total_payout
	total_payout = total_payout * mutators_multiplier
	crew_value = crew_value * mutators_multiplier
	stage_value = stage_value * mutators_multiplier
	stage_risk = stage_risk * mutators_multiplier
	job_value = job_value * mutators_multiplier
	job_risk = job_risk * mutators_multiplier
	bag_value = bag_value * mutators_multiplier
	bag_risk = bag_risk * mutators_multiplier
	vehicle_value = vehicle_value * mutators_multiplier
	vehicle_risk = vehicle_risk * mutators_multiplier
	small_value = small_value * mutators_multiplier
	local mutators_reduction = original_total_payout - total_payout
	
	-- RETURN TABLE --
	local ret = {
		stage_value, job_value, bag_value, vehicle_value, small_value, crew_value, total_payout,
		{ stage_risk = stage_risk, job_risk = job_risk, bag_risk = bag_risk, vehicle_risk = vehicle_risk, small_risk = small_risk },
		{ job_base_payout = base_static_value, job_risk_payout = risk_static_value }, mutators_reduction
	}

	return unpack(ret)
end

function MoneyManager:get_civilian_deduction()
	if managers.mutators:should_disable_statistics() then return 0 end

	local difficulty_stars = managers.job:has_active_job() and managers.job:current_difficulty_stars()
	
	if managers.crime_spree:is_active() then
		difficulty_stars = tweak_data.crime_spree.base_difficulty_index or difficulty_stars
	end

	local base = self:get_tweak_value("money_manager", "killing_civilian_deduction", difficulty_stars)
	local multiplier = managers.player:upgrade_value("player", "cleaner_cost_multiplier", 1)
	local stealth = managers.groupai and managers.groupai:state():whisper_mode()
	local total = stealth and math.round(base * multiplier) or 0

	return total
end