function MoneyTweakData:init(tweak_data, ...)
	local difficulty = Global.game_settings and Global.game_settings.difficulty or "normal"
	local difficulty_index = tweak_data:difficulty_to_index(difficulty) - 1
	self.offshore_rate = 0.25
	self.mandatory_mult = 0.75

	-- BAGS --
	self.bag_values = {
		default = 1000,
		money = 1750,
		counterfeit_money = 1500,
		gold = 3150,
		diamonds = 2000,
		diamonds_dah = 2150,
		rubies = 2400,
		coke = 2300,
		coke_pure = 3000,
		yayo = 2900,
		meth = 4800,
		meth_half = 6500,
		weapon = 2600,
		weapons = 2700,
		grenades = 2500,
		weapon_glock = 3100,
		weapon_scar = 3300,
		painting = 3000,
		samurai_suit = 6000,
		roman_armor = 5500,
		artifact_statue = 5000,
		mus_artifact = 3400,
		mus_artifact_paint = 3200,
		lost_artifact = 9600,
		chas_artifact = 5500,
		chas_teaset = 3200,
		faberge_egg = 3100,
		treasure = 3300,
		circuit = 1950,
		evidence_bag = 2800,
		warhead = 4600,
		safe = 4500,
		goat = 2500,
		vehicle_falcogini = 8800,
		turret = 12000,
		shells = 2100,
		hope_diamond = 30000,
		red_diamond = 25000,
		cro_loot1 = 10000,
		cro_loot2 = 11000,
		drk_bomb_part = 9000,
		unknown = 11500,
		box_unknown = 11500,
		black_tablet = 12000,
		prototype = 10000,
		master_server = 11000,
		masterpiece_painting = 12000,
		drone_control_helmet = 20000,
		sandwich = 11000,
		toothbrush = 18000,
		mad_master_server_value_1 = 5000,
		mad_master_server_value_2 = 11000,
		mad_master_server_value_3 = 24000,
		mad_master_server_value_4 = 30000,
		old_wine = 2500,
		din_pig = 2100,
		present = 2150,
		diamond_necklace = 2970,
		vr_headset = 2970,
		women_shoes = 2970,
		expensive_vine = 2970,
		ordinary_wine = 2970,
		robot_toy = 2970,
		cloaker_gold = 2450,
		cloaker_money = 1850,
		cloaker_cocaine = 2200,
	}

	self.difficulty_multiplier = { 5, 10, 15, 25, 35, 45, 50 }

	-- SMALL LOOT --
	self.small_loot = {
		gen_atm = 21000,
		slot_machine_payout = 25000,
		spawn_bucket_of_money = 27500,
		ring_band = 1950,
		money_bundle = 1000,
		diamondheist_vault_bust = 1200,
		diamondheist_vault_diamond = 1300,
		diamondheist_big_diamond = 1420,
		mus_small_artifact = 1400,
		vault_loot_chest = 1180,
		vault_loot_diamond_chest = 1320,
		vault_loot_banknotes = 1070,
		vault_loot_silver = 1380,
		vault_loot_diamond_collection = 1700,
		vault_loot_trophy = 1380,
		vault_loot_gold = 2500,
		vault_loot_cash = 1200,
		vault_loot_coins = 1100,
		vault_loot_ring = 1400,
		vault_loot_jewels = 1500,
		federali_medal = 1250,
	}

	local small_loot_dif_multiplier = { 1, 3, 7, 13, 18, 22, 26 }

	for i, val in pairs(self.small_loot) do
		local mult = small_loot_dif_multiplier[difficulty_index] or 1
		self.small_loot[i] = val * mult
	end

	self.max_small_loot_value = 2147000000

	-- HEIST REWARDS --
	self.difficulty_multiplier_payout = { 1, 2, 5, 10, 12, 15, 20 }
	self.alive_humans_multiplier = self._create_value_table(1, 1.1, tweak_data.max_players, false, 1)
	self.killing_civilian_deduction = self._create_value_table(50000, 500000, 7, true, 1)

	-- WEAPONS / MASKS --
	self.weapon_cost = self._create_value_table(5500000, 55000000, 40, true, 1.1)
	self.modify_weapon_cost = self._create_value_table(100000, 1000000, 10, true, 1.2)
	self.remove_weapon_mod_cost_multiplier = self._create_value_table(1, 1, 10, true, 1)
	self.masks = {
		mask_value = self._create_value_table(250000, 2500000, 10, true, 2),
		material_value = self._create_value_table(125000, 1250000, 10, true, 1.2),
		pattern_value = self._create_value_table(75000, 750000, 10, true, 1.1),
		color_value = self._create_value_table(50000, 500000, 10, true, 1)
	}
	self.sell_weapon_multiplier = 0.05
	self.sell_mask_multiplier = 0.05
	self.unlock_new_mask_slot_value = 2500000
	self.unlock_new_weapon_slot_value = 5000000

	-- ASSETS --
	self.mission_asset_cost_multiplier_by_risk = { 2, 4, 8, 10, 15, 20, 25 }
	self.mission_asset_cost_small = self._create_value_table(5500, 20000, 10, true, 1)
	self.mission_asset_cost_medium = self._create_value_table(22000, 50000, 10, true, 1)
	self.mission_asset_cost_large = self._create_value_table(55000, 100000, 10, true, 1)

	-- PREPLANNING --
	self.preplaning_asset_cost_multiplier_by_risk = { 3, 9, 15, 30, 45, 80, 120 }
	self.preplaning_asset_cost_thermite = 15000
	self.preplaning_asset_cost_escapebig = 10000
	self.preplaning_asset_cost_spycam = 1000
	self.preplaning_asset_cost_delay10 = 1000
	self.preplaning_asset_cost_delay20 = 1000
	self.preplaning_asset_cost_delay30 = 2000
	self.preplaning_asset_cost_timelock60 = 2000
	self.preplaning_asset_cost_cake = 3000
	self.preplaning_asset_cost_extracameras = 500
	self.preplaning_asset_cost_accesscameras = 1000
	self.preplaning_asset_cost_drillparts = 3000
	self.preplaning_asset_cost_deaddropbag = 1600
	self.preplaning_asset_cost_unlocked_door = 1000
	self.preplaning_asset_cost_unlocked_window = 1000
	self.preplaning_asset_cost_zipline = 2000
	self.preplaning_asset_cost_highlight_keybox = 1000
	self.preplaning_asset_cost_keycard = 2000
	self.preplaning_asset_cost_disable_alarm_button = 2000
	self.preplaning_asset_cost_safe_escape = 2000
	self.preplaning_asset_cost_sniper_spot = 2000
	self.preplaning_asset_cost_framing_frame_1_truck = 1000
	self.preplaning_asset_cost_framing_frame_1_entry_point = 1000
	self.preplaning_asset_cost_bag_shortcut = 2000
	self.preplaning_asset_cost_bag_zipline = 2000
	self.preplaning_asset_cost_loot_drop_off = 3000
	self.preplaning_asset_cost_thermal_paste = 3000
	self.preplaning_asset_cost_branchbank_vault_key = 3000
	self.preplaning_mia_cost_sniper = 3000
	self.preplaning_mia_cost_delayed_police = 2000
	self.preplaning_mia_cost_reduce_mobsters = 2000
	self.preplaning_asset_cost_glass_cutter = 1000
	self.preplaning_thebomb_cost_spotter = 4000
	self.preplaning_thebomb_cost_crowbar = 1000
	self.preplaning_thebomb_cost_ladder = 1000
	self.preplaning_thebomb_cost_hacker = 3000
	self.preplaning_thebomb_cost_manifest = 2000
	self.preplaning_thebomb_cost_pilot = 3000
	self.preplaning_thebomb_cost_escape_mid = 6000
	self.preplaning_thebomb_cost_escape_close = 10000
	self.preplaning_thebomb_cost_demolition = 500
	self.preplaning_asset_cost_roof_access = 2000
	self.preplaning_asset_cost_upper_floor_access = 1000
	self.preplaning_asset_cost_crowbar_single = 1000
	self.preplaning_asset_cost_mex_keys = 2000
	self.preplanning_asset_cost_bex_car_pull = 2000
	self.preplanning_asset_cost_bex_drunk_mariachi = 2000
	self.preplanning_asset_cost_bex_garbage_truck = 2000
	self.preplanning_asset_cost_bex_zipline = 2000
	self.preplanning_asset_cost_pex_parked_car = 2000
	self.preplanning_asset_cost_pex_spiked_churro = 2000
	self.preplanning_asset_cost_pex_camera_access = 2000
	self.preplanning_asset_cost_pex_open_window = 2000
	self.preplanning_asset_cost_fex_stealth_entry_with_boat = 2000
	self.preplanning_asset_cost_fex_loud_escape_with_heli = 2000
	self.preplanning_asset_cost_fex_stealth_semi_open_garage_door = 2000
	self.preplanning_asset_cost_kenaz_zeppelin_escape = 1000
	self.preplanning_asset_cost_kenaz_van_escape = 1000
	self.preplanning_asset_cost_kenaz_loud_entry_with_c4 = 1000
	self.preplanning_asset_cost_kenaz_wrecking_ball_escape = 1000
	self.preplanning_asset_cost_kenaz_drill_better_plasma_cutter = 1100
	self.preplanning_asset_cost_kenaz_drill_improved_cooling_system = 1200
	self.preplanning_asset_cost_kenaz_drill_engine_optimization = 1300
	self.preplanning_asset_cost_kenaz_drill_engine_additional_power = 1000
	self.preplanning_asset_cost_kenaz_drill_extra_battery = 1000
	self.preplanning_asset_cost_kenaz_drill_water_level_indicator = 1000
	self.preplanning_asset_cost_kenaz_drill_timer_addon = 1000
	self.preplanning_asset_cost_kenaz_drill_toolbox = 1000
	self.preplanning_asset_cost_kenaz_drill_medkit = 1000
	self.preplanning_asset_cost_kenaz_drill_ammobox = 1000
	self.preplanning_asset_cost_kenaz_ace_pilot = 2500
	self.preplanning_asset_cost_kenaz_faster_blimp = 1000
	self.preplanning_asset_cost_kenaz_rig_slotmachine = 1000
	self.preplanning_asset_cost_kenaz_sabotage_skylight_barrier = 1000
	self.preplanning_asset_cost_kenaz_customer_data_USB = 1000
	self.preplanning_asset_cost_kenaz_unlocked_cages = 500
	self.preplanning_asset_cost_kenaz_unlocked_doors = 500
	self.preplanning_asset_cost_kenaz_guitar_case_position = 1000
	self.preplanning_asset_cost_kenaz_disable_metal_detectors = 1000
	self.preplanning_asset_cost_kenaz_celebrity_visit = 2500
	self.preplanning_asset_cost_kenaz_vault_gate_key = 1000
	self.preplanning_asset_cost_chas_tram = 5000

	-- SKIlLS, PERKDECKS --
	self.skilltree = {
		respec = {
			base_cost = 200,
			profile_cost_increaser_multiplier = { 1, 1, 1, 1, 1, 1, 1, 1, 1, 1 },
			tier_cost = { 1500, 2000, 10000, 40000, 100000, 400000 },
			base_point_cost = 500,
			point_tier_cost = self._create_value_table(4000, 800000 * 0.18, 6, true, 1.1),
			respec_refund_multiplier = 0.6,
			point_cost = 0,
			point_multiplier_cost = 1,
		}
	}

	self.skill_switch_cost = {
		{ offshore = 0, spending = 0 },
		{ offshore = 0, spending = 0 },
		{ offshore = 1000000, spending = 100000 },
		{ offshore = 10000000, spending = 1000000 },
		{ offshore = 25000000, spending = 2500000 },
		{ offshore = 25000000, spending = 2500000 },
		{ offshore = 25000000, spending = 2500000 },
		{ offshore = 25000000, spending = 2500000 },
		{ offshore = 25000000, spending = 2500000 },
		{ offshore = 30000000, spending = 3000000 },
		{ offshore = 30000000, spending = 3000000 },
		{ offshore = 30000000, spending = 3000000 },
		{ offshore = 30000000, spending = 3000000 },
		{ offshore = 30000000, spending = 3000000 },
		{ offshore = 40000000, spending = 4000000 }
	}

	-- LOOTDROPS --
	self.loot_drop_cash = {
		cash10 = 100000,
		cash20 = 150000,
		cash30 = 200000,
		cash40 = 250000,
		cash50 = 300000,
		cash60 = 350000,
		cash70 = 400000,
		cash80 = 450000,
		cash90 = 500000,
		cash100 = 600000,
		cash_preorder = 800000
	}

	-- CASH BLASTER --
	self.moneythrower = {
		max_kills_per_session = 100,
		kill_to_offshore_multiplier = 1000
	}
end